@@ -48,6 +48,46 @@ class Slack:
         """Return an instance of the update class."""
         return Update(self, args, auth)
 
+    #
+    # admin usergroups
+    #
+    def admin_usergroups_add_channels(self, usergroup_id, channel_ids, team_id):
+        """Add a list of channels to a usergroup.."""
+        params = {
+            "usergroup_id": usergroup_id,
+            "channel_ids": ",".join(channel_ids),
+            "team_id": team_id,
+        }
+        return self.webclient.admin_usergroups_addChannels(**params)
+
+    def admin_usergroups_add_teams(self, usergroup_id, team_ids, auto_provision=False):
+        """Add a list of teams to a usergroup."""
+        params = {
+            "usergroup_id": usergroup_id,
+            "team_ids": ",".join(team_ids),
+            "auto_provision": auto_provision,
+        }
+        return self.webclient.admin_usergroups_addTeams(**params)
+
+    def admin_usergroups_list_channels(self, usergroup_id, include_num_members=False, team_id=None):
+        """Return a list of channels linked to an IDP Group."""
+        params = {
+            "usergroup_id": usergroup_id,
+            "include_num_members": include_num_members,
+        }
+        if team_id:
+            params["team_id"] = team_id
+        return self.webclient.admin_usergroups_listChannels(**params).data.get("channels", [])
+
+    def admin_usergroups_remove_channels(self, usergroup_id, channel_ids, team_id):
+        """Remove a list of channels from a usergroup.."""
+        params = {
+            "usergroup_id": usergroup_id,
+            "channel_ids": ",".join(channel_ids),
+            "team_id": team_id,
+        }
+        return self.webclient.admin_usergroups_removeChannels(**params)
+
     #
     # chat
     #
