@@ -242,6 +242,14 @@ class Update:
         self.slack_emails = emails
         return self.slack_emails
 
+    def _get_slack_group_sync_emails(self):
+        """Return a list of Slack Group sync emails from BITSdb Cloud."""
+        emails = []
+        for sync in self.auth.bitsdbapi().get_slack_group_syncs():
+            email = sync["google_group_email"]
+            emails.append(email)
+        return emails
+
     def _get_slack_usergroup_syncs(self):
         """Return a list of Slack Usergroup syncs from BITSdb."""
         emails = []
@@ -264,9 +272,11 @@ class Update:
 
     def _get_sync_group_emails(self):
         """Return a list of Google Group emails to sync."""
-        emails = [
-            "activebroadies@broadinstitute.org",
-        ]
+        if self.verbose:
+            print("Getting Slack Group Syncs from BITSdb Cloud API...")
+        emails = self._get_slack_group_sync_emails()
+        if self.verbose:
+            print(f"Group Sync Emails: {len(emails)}")
 
         if self.verbose:
             print("Getting Slack Usergroups Syncs from BITSdb Mongo DB...")
@@ -288,7 +298,7 @@ class Update:
             else:
                 print(f"Warning: Duplicate Sync Email: {email}")
 
-        return emails
+        return sorted(set(emails))
 
     def _prepare_idp_user(self, person):
         """Prepare a user for the Slack IDP."""
@@ -417,6 +427,20 @@ class Update:
         if self.verbose:
             print(f"People: {len(self.people)}")
 
+        for email in sorted(self.people):
+            if self.people[email]["terminated"]:
+                continue
+            if email not in self.scim_users:
+                print(f"Creating user: {email}...")
+                person = self.people[email]
+                idp_user = self._prepare_idp_user(person)
+                idp_user["emails"] = [{"value": email, "primary": True}]
+                try:
+                    user = scim.client.create_user(idp_user)
+                    print(f"  + Successfully created user: {user.id}")
+                except Exception as error:
+                    print(f"  ! Failed to create user: {error}")
+
         for email in self.scim_users:
             user = self.scim_users[email]
 
